﻿param($installPath, $toolsPath, $package, $project)

$analyzersDir = Join-Path (Split-Path -Path $toolsPath -Parent) "analyzers"
if (-Not (Test-Path $analyzersDir))
{
    return
}

$analyzersPaths = Join-Path ( $analyzersDir ) * -Resolve

foreach($analyzersPath in $analyzersPaths)
{
    # Uninstall the language agnostic analyzers.
    if (Test-Path $analyzersPath)
    {
        foreach ($analyzerFilePath in Get-ChildItem $analyzersPath -Filter *.dll)
        {
            if($project.Object.AnalyzerReferences)
            {
                $project.Object.AnalyzerReferences.Remove($analyzerFilePath.FullName)
            }
        }
    }
}

# $project.Type gives the language name like (C# or VB.NET)
$languageFolder = ""
if($project.Type -eq "C#")
{
    $languageFolder = "cs"
}
if($project.Type -eq "VB.NET")
{
    $languageFolder = "vb"
}
if($languageFolder -eq "")
{
    return
}

foreach($analyzersPath in $analyzersPaths)
{
    # Uninstall language specific analyzers.
    $languageAnalyzersPath = join-path $analyzersPath $languageFolder
    if (Test-Path $languageAnalyzersPath)
    {
        foreach ($analyzerFilePath in Get-ChildItem $languageAnalyzersPath -Filter *.dll)
        {
            if($project.Object.AnalyzerReferences)
            {
                try
                {
                    $project.Object.AnalyzerReferences.Remove($analyzerFilePath.FullName)
                }
                catch
                {

                }
            }
        }
    }
}
# SIG # Begin signature block
# MIIpQwYJKoZIhvcNAQcCoIIpNDCCKTACAQExDzANBglghkgBZQMEAgEFADB5Bgor
# BgEEAYI3AgEEoGswaTA0BgorBgEEAYI3AgEeMCYCAwEAAAQQH8w7YFlLCE63JNLG
# KX7zUQIBAAIBAAIBAAIBAAIBADAxMA0GCWCGSAFlAwQCAQUABCB5mT/HBF+ApGFF
# NurlQsK+/gKFs6a98ziX+/GaLDsVJqCCDfQwggZyMIIEWqADAgECAhMzAAAEPxXT
# o2me74nMAAAAAAQ/MA0GCSqGSIb3DQEBDAUAMH4xCzAJBgNVBAYTAlVTMRMwEQYD
# VQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNy
# b3NvZnQgQ29ycG9yYXRpb24xKDAmBgNVBAMTH01pY3Jvc29mdCBDb2RlIFNpZ25p
# bmcgUENBIDIwMTEwHhcNMjQxMTE5MTk1MDU4WhcNMjUxMTEyMTk1MDU4WjBjMQsw
# CQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9u
# ZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMQ0wCwYDVQQDEwQuTkVU
# MIIBojANBgkqhkiG9w0BAQEFAAOCAY8AMIIBigKCAYEAqsr+k9yh9dU/cF9B1Ko8
# T6SaoJNg9kJYh809q0GBZq1WrDbRGcgAClcMmMtAFgIps7Fimyyw/ympDR2Zila5
# iDwHRPpPefdumtlFE2iLDgoZHDXoOs2DdZZza5tYKaA8rmq8vmIh6JfvXHqtlWJd
# s6hAxzHrimvJHUF+Kq5T8n8bRbzOUHbfrvvIYDlQ5YXu1tCFU9mEcVe0y+A3VgsZ
# gEobuJ8UB64Snm0P3eJRNYMELzuNZuwRK+X3VF87u4VRM7t18/csk7ANACbO8/nC
# tT5NzsAdobodUQoSevvY8b474GO9QdMFjXN6PF7oxGq0fT617VN0Nizkl4qAVa9c
# qBhplDelQ20xjzOnFTpHhp9j7/9neYBYkonH9EnLWkIHfCQ7NlDT6vSVyD/tswb9
# jQK7jj5klCrPx9UL3/T7zWCBGbNGp7ylExVt4crtI42CVGC7YpH/IEO2CeCszVVy
# HslZxycPBmRRGBzvLwodkYTl9HnsDMVjnlucqsbWNeqdAgMBAAGjggGCMIIBfjAf
# BgNVHSUEGDAWBgorBgEEAYI3TAgBBggrBgEFBQcDAzAdBgNVHQ4EFgQULPGeoivj
# /NcRbrh1VDqlXOI1df0wVAYDVR0RBE0wS6RJMEcxLTArBgNVBAsTJE1pY3Jvc29m
# dCBJcmVsYW5kIE9wZXJhdGlvbnMgTGltaXRlZDEWMBQGA1UEBRMNNDY0MjIzKzUw
# MzM5MjAfBgNVHSMEGDAWgBRIbmTlUAXTgqoXNzcitW2oynUClTBUBgNVHR8ETTBL
# MEmgR6BFhkNodHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20vcGtpb3BzL2NybC9NaWND
# b2RTaWdQQ0EyMDExXzIwMTEtMDctMDguY3JsMGEGCCsGAQUFBwEBBFUwUzBRBggr
# BgEFBQcwAoZFaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3BraW9wcy9jZXJ0cy9N
# aWNDb2RTaWdQQ0EyMDExXzIwMTEtMDctMDguY3J0MAwGA1UdEwEB/wQCMAAwDQYJ
# KoZIhvcNAQEMBQADggIBAKiH9gTsKkb1QsFOWaiSF1sUpJ/aboTO7pn5eafSaeup
# pt9KVvZaZbZOonaTWyfR9k4M/WPBsyRaIQRDvEhlB1JCcSHUe3TxFdYMyA0ZLLGV
# uUahdJ7KiNo0HrFtQbhtIo/SwcoezS06kShkDx4/PMlSdsp/woebzjuab7sgvSXy
# sX97vj1ZQlESvgldF2wAg5+C0wKCLdB43/H08gq53PcZQ2s5qDvqluZ0tFjNmPEH
# Kh+kaG+xTZCRJQGf/mrTmBlRtKcL293EXNtEO344ybYNoCO7snEI5Ine3vjJgd66
# J7HJqrSYPiKjEZ1KH85n8A6ivR4LlsL87gqrr41NPR6mN3KA3lqWd2jpnS0I7T8W
# Nqk1k9aQQlXHQ8V+TRwvXdDlh5OdIEQ/xrR21yV+lDGjkWsyjeX2UgOg0wFDcX90
# PVPGXP8DPvZb04P38npzWrfKwmyQC3gCA91dfXOg6g9AmUJKZvQbdcEcoZhLw9dt
# 6MM2149eeaz6QIprT6marM21TGXp40N/v/5MXeAk/7LySCHUJWiaIt9lfyOtKdDT
# hSNPFTuXcINaDJOBcY21ranmTsLd/3FKw+Z5UpvxHA83W0qRBq6t5I/C5AKrQZho
# mPyA7QyVsDHs3ekXXZQ11v203ACerQ2KnquSR7gE25yfcz3vF1VV4IA/7HKts8dy
# MIIHejCCBWKgAwIBAgIKYQ6Q0gAAAAAAAzANBgkqhkiG9w0BAQsFADCBiDELMAkG
# A1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQx
# HjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEyMDAGA1UEAxMpTWljcm9z
# b2Z0IFJvb3QgQ2VydGlmaWNhdGUgQXV0aG9yaXR5IDIwMTEwHhcNMTEwNzA4MjA1
# OTA5WhcNMjYwNzA4MjEwOTA5WjB+MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2Fz
# aGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENv
# cnBvcmF0aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBTaWduaW5nIFBDQSAy
# MDExMIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAq/D6chAcLq3YbqqC
# EE00uvK2WCGfQhsqa+laUKq4BjgaBEm6f8MMHt03a8YS2AvwOMKZBrDIOdUBFDFC
# 04kNeWSHfpRgJGyvnkmc6Whe0t+bU7IKLMOv2akrrnoJr9eWWcpgGgXpZnboMlIm
# Ei/nqwhQz7NEt13YxC4Ddato88tt8zpcoRb0RrrgOGSsbmQ1eKagYw8t00CT+OPe
# Bw3VXHmlSSnnDb6gE3e+lD3v++MrWhAfTVYoonpy4BI6t0le2O3tQ5GD2Xuye4Yb
# 2T6xjF3oiU+EGvKhL1nkkDstrjNYxbc+/jLTswM9sbKvkjh+0p2ALPVOVpEhNSXD
# OW5kf1O6nA+tGSOEy/S6A4aN91/w0FK/jJSHvMAhdCVfGCi2zCcoOCWYOUo2z3yx
# kq4cI6epZuxhH2rhKEmdX4jiJV3TIUs+UsS1Vz8kA/DRelsv1SPjcF0PUUZ3s/gA
# 4bysAoJf28AVs70b1FVL5zmhD+kjSbwYuER8ReTBw3J64HLnJN+/RpnF78IcV9uD
# jexNSTCnq47f7Fufr/zdsGbiwZeBe+3W7UvnSSmnEyimp31ngOaKYnhfsi+E11ec
# XL93KCjx7W3DKI8sj0A3T8HhhUSJxAlMxdSlQy90lfdu+HggWCwTXWCVmj5PM4Ta
# sIgX3p5O9JawvEagbJjS4NaIjAsCAwEAAaOCAe0wggHpMBAGCSsGAQQBgjcVAQQD
# AgEAMB0GA1UdDgQWBBRIbmTlUAXTgqoXNzcitW2oynUClTAZBgkrBgEEAYI3FAIE
# DB4KAFMAdQBiAEMAQTALBgNVHQ8EBAMCAYYwDwYDVR0TAQH/BAUwAwEB/zAfBgNV
# HSMEGDAWgBRyLToCMZBDuRQFTuHqp8cx0SOJNDBaBgNVHR8EUzBRME+gTaBLhklo
# dHRwOi8vY3JsLm1pY3Jvc29mdC5jb20vcGtpL2NybC9wcm9kdWN0cy9NaWNSb29D
# ZXJBdXQyMDExXzIwMTFfMDNfMjIuY3JsMF4GCCsGAQUFBwEBBFIwUDBOBggrBgEF
# BQcwAoZCaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3BraS9jZXJ0cy9NaWNSb29D
# ZXJBdXQyMDExXzIwMTFfMDNfMjIuY3J0MIGfBgNVHSAEgZcwgZQwgZEGCSsGAQQB
# gjcuAzCBgzA/BggrBgEFBQcCARYzaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3Br
# aW9wcy9kb2NzL3ByaW1hcnljcHMuaHRtMEAGCCsGAQUFBwICMDQeMiAdAEwAZQBn
# AGEAbABfAHAAbwBsAGkAYwB5AF8AcwB0AGEAdABlAG0AZQBuAHQALiAdMA0GCSqG
# SIb3DQEBCwUAA4ICAQBn8oalmOBUeRou09h0ZyKbC5YR4WOSmUKWfdJ5DJDBZV8u
# LD74w3LRbYP+vj/oCso7v0epo/Np22O/IjWll11lhJB9i0ZQVdgMknzSGksc8zxC
# i1LQsP1r4z4HLimb5j0bpdS1HXeUOeLpZMlEPXh6I/MTfaaQdION9MsmAkYqwooQ
# u6SpBQyb7Wj6aC6VoCo/KmtYSWMfCWluWpiW5IP0wI/zRive/DvQvTXvbiWu5a8n
# 7dDd8w6vmSiXmE0OPQvyCInWH8MyGOLwxS3OW560STkKxgrCxq2u5bLZ2xWIUUVY
# ODJxJxp/sfQn+N4sOiBpmLJZiWhub6e3dMNABQamASooPoI/E01mC8CzTfXhj38c
# bxV9Rad25UAqZaPDXVJihsMdYzaXht/a8/jyFqGaJ+HNpZfQ7l1jQeNbB5yHPgZ3
# BtEGsXUfFL5hYbXw3MYbBL7fQccOKO7eZS/sl/ahXJbYANahRr1Z85elCUtIEJmA
# H9AAKcWxm6U/RXceNcbSoqKfenoi+kiVH6v7RyOA9Z74v2u3S5fi63V4GuzqN5l5
# GEv/1rMjaHXmr/r8i+sLgOppO6/8MO0ETI7f33VtY5E90Z1WTk+/gFcioXgRMiF6
# 70EKsT/7qMykXcGhiJtXcVZOSEXAQsmbdlsKgEhr/Xmfwb1tbWrJUnMTDXpQzTGC
# GqUwghqhAgEBMIGVMH4xCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9u
# MRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRp
# b24xKDAmBgNVBAMTH01pY3Jvc29mdCBDb2RlIFNpZ25pbmcgUENBIDIwMTECEzMA
# AAQ/FdOjaZ7vicwAAAAABD8wDQYJYIZIAWUDBAIBBQCgga4wGQYJKoZIhvcNAQkD
# MQwGCisGAQQBgjcCAQQwHAYKKwYBBAGCNwIBCzEOMAwGCisGAQQBgjcCARUwLwYJ
# KoZIhvcNAQkEMSIEILtEeMEUesXcycnvAB00C1m+1XkEcUBjfhNIN2IZgfkZMEIG
# CisGAQQBgjcCAQwxNDAyoBSAEgBNAGkAYwByAG8AcwBvAGYAdKEagBhodHRwOi8v
# d3d3Lm1pY3Jvc29mdC5jb20wDQYJKoZIhvcNAQEBBQAEggGAULzdp5VrWNT8rTbj
# hwMJm2a+w40eug68HQCMsdaHPLOCwGkIIwraAt08Y8QETBro/I6GuNe2tYsdBYad
# e4+Dq/GS8w9eAhI2M8dBiqes8NncSxYQzFCJDq/Q+/mFE5JowphFb8UOaflcoDsk
# 9guNZlqPc8T7Tde/d5X0us5ZJ7zY+SeIpqwEwqlkP5HkzT9TFDSNVWmSMLLm8BMz
# ghxeysWsZW3+p7WGcGd/eF39Pk8xY5XRX6SRBqgjdzbTn2eFkRQPRmUrGnAn5uaA
# /ROuwFcDevWGmWT1PSV26kMOZs1E9tJYNYy+vnM6f56vdLuYGwtcG96g+/2hCvYy
# /ioNpmDroBo+3oygfiVf6WPnYgAn141Nu8ZYZOXz+rK9Cy3zIUyUqEUd0GQjFHQv
# uwLeRwqwRt6XabZkPD4F1qnJPAzth2VSnC3Vz6ApTXUti9p94NOgaZD9Et054mij
# zv3nBqxejItxHkQqtQHTQPPcWFjGshZ/kWhl1uE6BUTTvGPfoYIXrzCCF6sGCisG
# AQQBgjcDAwExghebMIIXlwYJKoZIhvcNAQcCoIIXiDCCF4QCAQMxDzANBglghkgB
# ZQMEAgEFADCCAVkGCyqGSIb3DQEJEAEEoIIBSASCAUQwggFAAgEBBgorBgEEAYRZ
# CgMBMDEwDQYJYIZIAWUDBAIBBQAEIBo6rZ+ZAgGGk2RXueZ24Cs4Xlwfnw6UaRLH
# 88usDd9OAgZnti1OVccYEjIwMjUwMzIzMDgxNzQ3LjA3WjAEgAIB9KCB2aSB1jCB
# 0zELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1Jl
# ZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEtMCsGA1UECxMk
# TWljcm9zb2Z0IElyZWxhbmQgT3BlcmF0aW9ucyBMaW1pdGVkMScwJQYDVQQLEx5u
# U2hpZWxkIFRTUyBFU046NTcxQS0wNUUwLUQ5NDcxJTAjBgNVBAMTHE1pY3Jvc29m
# dCBUaW1lLVN0YW1wIFNlcnZpY2WgghH+MIIHKDCCBRCgAwIBAgITMwAAAfvLy2w3
# Z+UwlQABAAAB+zANBgkqhkiG9w0BAQsFADB8MQswCQYDVQQGEwJVUzETMBEGA1UE
# CBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9z
# b2Z0IENvcnBvcmF0aW9uMSYwJAYDVQQDEx1NaWNyb3NvZnQgVGltZS1TdGFtcCBQ
# Q0EgMjAxMDAeFw0yNDA3MjUxODMxMTNaFw0yNTEwMjIxODMxMTNaMIHTMQswCQYD
# VQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEe
# MBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMS0wKwYDVQQLEyRNaWNyb3Nv
# ZnQgSXJlbGFuZCBPcGVyYXRpb25zIExpbWl0ZWQxJzAlBgNVBAsTHm5TaGllbGQg
# VFNTIEVTTjo1NzFBLTA1RTAtRDk0NzElMCMGA1UEAxMcTWljcm9zb2Z0IFRpbWUt
# U3RhbXAgU2VydmljZTCCAiIwDQYJKoZIhvcNAQEBBQADggIPADCCAgoCggIBAKjC
# VkHlgKuC8L0o2LIz9FL4b5tI9GgDiYjC4NLC38SqE1wHSg+qDLquaxeaBIjsVfva
# MdB/eUPH4aGat8fZcYLmckziuJdsbXILSQrY10ZZTNm06YzoN+UVKwctHAJaAVPR
# iQbOywTa3Gx+qwYjr6g0DYnD0WcKtescozInVNSdQCbmrfci5+7Won6A+fG5WBHA
# b5I+XR9ZWvc1POOkA3jqETujXKhy7A8fP81SmcT99JlumO0TLKrQfHBgoBsFVbqz
# p2jS17N9ak0U8lR1/KaTnaEooQl3qnm4CQkcxvMxv3v5NKGgYxRRpfvLhRC8Asoe
# MCvWefms0832thg+KeoobbJF7N5Z1tOVCnwyYQAA7er4jnNEZP3PMzoqs4dJSqX/
# 3llGNqP4b3Az2TYC2h78nw6m/AFmirzt+okWUl6oUsPEsSaNEwqbGwo5rcdC6R56
# m29VBe3KtPZAnH1kwz3DddqW2C6nJNGyCHzym3Ox565DUJLP5km1WU5w8k9zvMxf
# auAwn1nrEq9WpMnA3bhsQnSgb4LSYdWMQ6tbJE8HmMeYgFl5weyjMpbN1kGW07m0
# wiy7fF5/LfrJXCpuQ5L6G7m5h0q4rkwN8E8iMuBcWpkyptFQ7vZlnbPDLY1EiVcD
# VVZQV2kN2THFY4o8laFDVbgWPTHMGHCECutsENtBAgMBAAGjggFJMIIBRTAdBgNV
# HQ4EFgQUR1UhmFDUN0cDpe9cyALlIyCoNSowHwYDVR0jBBgwFoAUn6cVXQBeYl2D
# 9OXSZacbUzUZ6XIwXwYDVR0fBFgwVjBUoFKgUIZOaHR0cDovL3d3dy5taWNyb3Nv
# ZnQuY29tL3BraW9wcy9jcmwvTWljcm9zb2Z0JTIwVGltZS1TdGFtcCUyMFBDQSUy
# MDIwMTAoMSkuY3JsMGwGCCsGAQUFBwEBBGAwXjBcBggrBgEFBQcwAoZQaHR0cDov
# L3d3dy5taWNyb3NvZnQuY29tL3BraW9wcy9jZXJ0cy9NaWNyb3NvZnQlMjBUaW1l
# LVN0YW1wJTIwUENBJTIwMjAxMCgxKS5jcnQwDAYDVR0TAQH/BAIwADAWBgNVHSUB
# Af8EDDAKBggrBgEFBQcDCDAOBgNVHQ8BAf8EBAMCB4AwDQYJKoZIhvcNAQELBQAD
# ggIBAMM6CCjmNnZ1I31rjIhqM/6L6HNXvOlcFmmTRXYEZjqELkXuJy3bWTjbUxzZ
# N0o955MgbM88Um2RENA3bsihxyOT/FfO4xbbRp5UdMDz9thQHm27wG7rZDDFUDBc
# 4VQVolg9FQJ7vcdH44nyygwFVy8KLp+awhasG2rFxXOx/9Az4gvgwZ97VMXn73MV
# AsrOPgwt7PAmKe1ll6WfFm/73QYQ5Yh5ge6VnJrAfN7nOPz9hpgCNxzJDhLu3wmk
# mKEIaLljq9O5fyjOE53cpSIq5vH9lsF0HBRM5lLyEjOpbnVMBpVTX00yVKtm0wxH
# d7ZQyrVfQFGN665xcB08Ca8i7U+CBYb4AXzQ95i9XnkmpCn+8UyCOCcrdeUl4R3e
# aCP1xo0oMpICa1gOe6xpwAu67t/2WxTQjCvyY+l/F+C+pgTmGtjRisB+AN+2Bg63
# nCf6l11lGL3y2Khxn/E4WJddmINa8EiqVi6JQPwdXqgcOE0XL1WNCLzTYubJvv/x
# yfQMOjSbkf7g0e1+7w14nKVzJUTYBTMgA2/ABSL0D3R6nEaUaK2PmFBpb83icf9o
# DWMnswKJG6xYQArCdgX8ni8ghKOgLsBB5+ddTyhPHSuCb5Zi0qB4+1RUdzRw5N80
# ZMdBMZJhfGjnab6CobsAQsaGfyYW80s672e+BlYyiiMreRQNMIIHcTCCBVmgAwIB
# AgITMwAAABXF52ueAptJmQAAAAAAFTANBgkqhkiG9w0BAQsFADCBiDELMAkGA1UE
# BhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAc
# BgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEyMDAGA1UEAxMpTWljcm9zb2Z0
# IFJvb3QgQ2VydGlmaWNhdGUgQXV0aG9yaXR5IDIwMTAwHhcNMjEwOTMwMTgyMjI1
# WhcNMzAwOTMwMTgzMjI1WjB8MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGlu
# Z3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBv
# cmF0aW9uMSYwJAYDVQQDEx1NaWNyb3NvZnQgVGltZS1TdGFtcCBQQ0EgMjAxMDCC
# AiIwDQYJKoZIhvcNAQEBBQADggIPADCCAgoCggIBAOThpkzntHIhC3miy9ckeb0O
# 1YLT/e6cBwfSqWxOdcjKNVf2AX9sSuDivbk+F2Az/1xPx2b3lVNxWuJ+Slr+uDZn
# hUYjDLWNE893MsAQGOhgfWpSg0S3po5GawcU88V29YZQ3MFEyHFcUTE3oAo4bo3t
# 1w/YJlN8OWECesSq/XJprx2rrPY2vjUmZNqYO7oaezOtgFt+jBAcnVL+tuhiJdxq
# D89d9P6OU8/W7IVWTe/dvI2k45GPsjksUZzpcGkNyjYtcI4xyDUoveO0hyTD4MmP
# frVUj9z6BVWYbWg7mka97aSueik3rMvrg0XnRm7KMtXAhjBcTyziYrLNueKNiOSW
# rAFKu75xqRdbZ2De+JKRHh09/SDPc31BmkZ1zcRfNN0Sidb9pSB9fvzZnkXftnIv
# 231fgLrbqn427DZM9ituqBJR6L8FA6PRc6ZNN3SUHDSCD/AQ8rdHGO2n6Jl8P0zb
# r17C89XYcz1DTsEzOUyOArxCaC4Q6oRRRuLRvWoYWmEBc8pnol7XKHYC4jMYcten
# IPDC+hIK12NvDMk2ZItboKaDIV1fMHSRlJTYuVD5C4lh8zYGNRiER9vcG9H9stQc
# xWv2XFJRXRLbJbqvUAV6bMURHXLvjflSxIUXk8A8FdsaN8cIFRg/eKtFtvUeh17a
# j54WcmnGrnu3tz5q4i6tAgMBAAGjggHdMIIB2TASBgkrBgEEAYI3FQEEBQIDAQAB
# MCMGCSsGAQQBgjcVAgQWBBQqp1L+ZMSavoKRPEY1Kc8Q/y8E7jAdBgNVHQ4EFgQU
# n6cVXQBeYl2D9OXSZacbUzUZ6XIwXAYDVR0gBFUwUzBRBgwrBgEEAYI3TIN9AQEw
# QTA/BggrBgEFBQcCARYzaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3BraW9wcy9E
# b2NzL1JlcG9zaXRvcnkuaHRtMBMGA1UdJQQMMAoGCCsGAQUFBwMIMBkGCSsGAQQB
# gjcUAgQMHgoAUwB1AGIAQwBBMAsGA1UdDwQEAwIBhjAPBgNVHRMBAf8EBTADAQH/
# MB8GA1UdIwQYMBaAFNX2VsuP6KJcYmjRPZSQW9fOmhjEMFYGA1UdHwRPME0wS6BJ
# oEeGRWh0dHA6Ly9jcmwubWljcm9zb2Z0LmNvbS9wa2kvY3JsL3Byb2R1Y3RzL01p
# Y1Jvb0NlckF1dF8yMDEwLTA2LTIzLmNybDBaBggrBgEFBQcBAQROMEwwSgYIKwYB
# BQUHMAKGPmh0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9wa2kvY2VydHMvTWljUm9v
# Q2VyQXV0XzIwMTAtMDYtMjMuY3J0MA0GCSqGSIb3DQEBCwUAA4ICAQCdVX38Kq3h
# LB9nATEkW+Geckv8qW/qXBS2Pk5HZHixBpOXPTEztTnXwnE2P9pkbHzQdTltuw8x
# 5MKP+2zRoZQYIu7pZmc6U03dmLq2HnjYNi6cqYJWAAOwBb6J6Gngugnue99qb74p
# y27YP0h1AdkY3m2CDPVtI1TkeFN1JFe53Z/zjj3G82jfZfakVqr3lbYoVSfQJL1A
# oL8ZthISEV09J+BAljis9/kpicO8F7BUhUKz/AyeixmJ5/ALaoHCgRlCGVJ1ijbC
# HcNhcy4sa3tuPywJeBTpkbKpW99Jo3QMvOyRgNI95ko+ZjtPu4b6MhrZlvSP9pEB
# 9s7GdP32THJvEKt1MMU0sHrYUP4KWN1APMdUbZ1jdEgssU5HLcEUBHG/ZPkkvnNt
# yo4JvbMBV0lUZNlz138eW0QBjloZkWsNn6Qo3GcZKCS6OEuabvshVGtqRRFHqfG3
# rsjoiV5PndLQTHa1V1QJsWkBRH58oWFsc/4Ku+xBZj1p/cvBQUl+fpO+y/g75LcV
# v7TOPqUxUYS8vwLBgqJ7Fx0ViY1w/ue10CgaiQuPNtq6TPmb/wrpNPgkNWcr4A24
# 5oyZ1uEi6vAnQj0llOZ0dFtq0Z4+7X6gMTN9vMvpe784cETRkPHIqzqKOghif9lw
# Y1NNje6CbaUFEMFxBmoQtB1VM1izoXBm8qGCA1kwggJBAgEBMIIBAaGB2aSB1jCB
# 0zELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1Jl
# ZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEtMCsGA1UECxMk
# TWljcm9zb2Z0IElyZWxhbmQgT3BlcmF0aW9ucyBMaW1pdGVkMScwJQYDVQQLEx5u
# U2hpZWxkIFRTUyBFU046NTcxQS0wNUUwLUQ5NDcxJTAjBgNVBAMTHE1pY3Jvc29m
# dCBUaW1lLVN0YW1wIFNlcnZpY2WiIwoBATAHBgUrDgMCGgMVAARx5+zQhrrGc9kX
# 1W8rsGMD8pAVoIGDMIGApH4wfDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hp
# bmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jw
# b3JhdGlvbjEmMCQGA1UEAxMdTWljcm9zb2Z0IFRpbWUtU3RhbXAgUENBIDIwMTAw
# DQYJKoZIhvcNAQELBQACBQDrijB2MCIYDzIwMjUwMzIzMDcwMjE0WhgPMjAyNTAz
# MjQwNzAyMTRaMHcwPQYKKwYBBAGEWQoEATEvMC0wCgIFAOuKMHYCAQAwCgIBAAIC
# ALUCAf8wBwIBAAICEnowCgIFAOuLgfYCAQAwNgYKKwYBBAGEWQoEAjEoMCYwDAYK
# KwYBBAGEWQoDAqAKMAgCAQACAwehIKEKMAgCAQACAwGGoDANBgkqhkiG9w0BAQsF
# AAOCAQEAyEYOb9QFiuMrenA0+Ua4WtoerfjDOPbwb2R0n4h3bNuIoyjvtNSlZRgP
# Q1Gmxp9NO0Ch1UZcA55ri//Aje5/tNqIKSphgko4PCRR8tgsaPCvd+ejpwtSAixy
# vprW4fbM+HWT2oAq7qjgVmWpOEKSgHqY/OoSE3++EHMwotR85N1IDjbNWoLCryQh
# dSDhAUAIEIp6uQGS8JsKCIFpsRbonO6UjH/7KoFrQocghfNO0zOoeYQGZLQkFC7N
# FAf7CLfrYqa5FELUKoQXvAmJI+43lhJXb1iZQyDVEZRU9xk7HaKKOCsZWpmp7ARM
# DXeWKW74NADHLQ732O1aYmnaqKQQezGCBA0wggQJAgEBMIGTMHwxCzAJBgNVBAYT
# AlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYD
# VQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xJjAkBgNVBAMTHU1pY3Jvc29mdCBU
# aW1lLVN0YW1wIFBDQSAyMDEwAhMzAAAB+8vLbDdn5TCVAAEAAAH7MA0GCWCGSAFl
# AwQCAQUAoIIBSjAaBgkqhkiG9w0BCQMxDQYLKoZIhvcNAQkQAQQwLwYJKoZIhvcN
# AQkEMSIEIMSRBB9l79rZ0ggv47dCSEvKToqp0FWRe4DGAbVdKUtwMIH6BgsqhkiG
# 9w0BCRACLzGB6jCB5zCB5DCBvQQgOdsCq/yghZVTWIlrAi7AeKoYxGBD98R6mKg7
# tUkk5RgwgZgwgYCkfjB8MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3Rv
# bjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0
# aW9uMSYwJAYDVQQDEx1NaWNyb3NvZnQgVGltZS1TdGFtcCBQQ0EgMjAxMAITMwAA
# AfvLy2w3Z+UwlQABAAAB+zAiBCBb3Xow3cPZ8R9uoAm8QDtMIhvmrpDb5Ho2SDEq
# WKUxtzANBgkqhkiG9w0BAQsFAASCAgAq28AAV9mENid7A5wtQbe1CByFa6QOBIcL
# /FdLiIzhm5ifEQpV9YZ744FT6XXFKw6/+Rt+3J9ylwe23JjdFh7EBVYrWLNsJ5kO
# M9pNku1vbArt2vJGPiQ09Pltu9w7Ysj1ePobcgWveAWFjSXsj4u5CNQYaSVS2WWi
# t2HgOWi02B7n/3RP4VpkhOD7tDpJ/2wadKWPy0nf6wk38xsZNETzPta4ubVGaggN
# 2+/4YAs7dNHReu8ffeX5H0zaxWTek9WcXqoJzYAyxxBTJSi/WES0X9OhGVLTyXpA
# biSAdY0RERYrTHH66IEueBY6XHX9P1TBSnI2jznIuVTBzfccQtwfn4egy8ZqTyQD
# hBKF6lz4cw1h5qL2y+L/2mBa8QJQ1LrJRwlck/FPIXH3cj6jUYWxDVkBRlbyjLoV
# wF9TG38KHNGIQtP3NrwNkyVS0GSB/HPF0lcOZhvtu62W5jRQATGT4bH2++yEKdrg
# I4GVoZdiB40GkKgFr1d6BXx1FGNYldqXHLYschn3eCrQ0kxJ6ch7xpeFoO1FXHVt
# kXBoae/4TlJM9gz6D5pUjBdLHtmrUQudew8kn68C+eyUy0woS/Fnz2VpApifuSiA
# 87w0I2pVP2IiMNN0iSmjONKP05k8lwps8nRsk5xaWGr7N+x39K9InUIL+qDFJfdC
# JAAdaGNC9Q==
# SIG # End signature block
